#!/bin/sh

name="siemfeeder"

scriptname="$0"

# SIEMFeeder directory
DIR="$(realpath $(dirname $scriptname))"

# needed utils
restorecon="$(command -v restorecon)"
semanage="$(command -v semanage)"

# selinux file for custom/local labels
local_context="/etc/selinux/targeted/contexts/files/file_contexts.local"

function fatal
{
    echo
    echo "[!] $1"
    echo
    exit
}

function log
{
    echo "[+] $1"
}

function error
{
    echo "[!] $1"
}

function main
{
    uid=$(id -u)
    if [ $uid -ne 0 ]; then
        fatal "$0 must be executed as root"
    fi

    if [ -z $restorecon -o -z $semanage ]; then
        fatal "restorecon or semanage binaries not found. Verify that selinux is configured and the utils installed (semanage, restorecon, ...)"
    fi

    log "Using path: $DIR"
}

function apply_selinux_labels
{
    $($restorecon -R -v "$DIR" 1>/dev/null)
}

# remove: semanage fcontext -d -t bin_t "/home/panda/Desktop/SIEMFeeder-3.1-Linux-pro(/.*)?"
function make_selinux_labels_permanent
{
    #echo "$DIR(/.*)?    system_u:object_r:bin_t:s0" >> /etc/selinux/targeted/contexts/files/file_contexts.local
    $($semanage fcontext -a -t bin_t "$DIR(/.*)?")
    apply_selinux_labels
}

function is_selinux_label_permanent
{
    grep -i "$name.*bin_t" /etc/selinux/targeted/contexts/files/file_contexts.local &>/dev/null
    return $?
}

function has_selinux_label
{
    ls -Z $DIR/* 2>/dev/null | grep bin_t &>/dev/null
    return $?
}

main

if ! has_selinux_label; then
    log "needs selinux relabeling"
    log "adding selinux label"
    make_selinux_labels_permanent

    if ! has_selinux_label; then
        log "selinux labels not applied. REVIEW (ls -lZ $DIR/)"
    fi
    if ! is_selinux_label_permanent; then
        fatal "failed adding permanent selinux label. Run in debug mode with 'bash -x $scriptname'"
    else
        log "selinux label applied"
    fi
else
    log "$name directory correctly labelled."
    if ! is_selinux_label_permanent; then
        make_selinux_labels_permanent
    fi
fi


if has_selinux_label -a is_selinux_label_permanent; then
    log "all good, done."
else
    error "something went wrong. Run in debug mode with 'bash -x $scriptname'"
fi

echo
